@@ -276,7 +276,7 @@ class Chip_TMC5031(i2c.I2CChip):
 
     def init_spi_bridge(self):    
         self.spi_bridge_config_spi(0x0c)  # 0x0c = ORDER=MSB first,  MODE0/1=CPHA=1, CPOL=1, F0/1(SPI_Clk)=1.8MHz
-        self.spi_bridge_gpio_config(0x50) #  eDrvEnSlave(SlaveSelect2 + SlaveSelect3) = Push-Pull output
+        self.spi_bridge_gpio_config(0x55) #  select all pins to Push-Pull output 
         self.spi_bridge_gpio_enable(Chip_TMC5031.SPI_Function_IDS.config_spi.slave_select_23) # activate DrvEn-Signal as GPIO 
         self.spi_bridge_gpio_write(0xff)  # Disable all (1 = off, 0 = on)
 
