@@ -9,8 +9,15 @@
 
 from enum import IntEnum
 import typing
-from PySide2 import QtGui, QtWidgets
-from PySide2.QtCore import Qt, Signal
+
+from nanosurf.lib.gui.import_helper import import_pyside2_if_none_is_detected
+if import_pyside2_if_none_is_detected():
+    from PySide2 import QtGui, QtWidgets
+    from PySide2.QtCore import Qt, Signal
+else:
+    from PySide6 import QtGui, QtWidgets
+    from PySide6.QtCore import Qt, Signal
+
 from nanosurf.lib.gui.nsf_widgets_common import LabelWidgetSize, WidgetLayout
 
 class NSFComboEntry():
