@@ -5,7 +5,13 @@ License - MIT
 
 import enum
 import typing
-from PySide2 import QtWidgets, QtCore
+
+from nanosurf.lib.gui.import_helper import import_pyside2_if_none_is_detected
+if import_pyside2_if_none_is_detected():
+   from PySide2 import QtWidgets, QtCore
+else:
+   from PySide6 import QtWidgets, QtCore
+
 import nanosurf.lib.datatypes.sci_val as sci_val
 
 class TableEntryIDs(enum.IntEnum):
