@@ -1,4 +1,4 @@
-"""Package for scripting the Nansurf control software.
+"""Package for scripting the Nanosurf control software.
 Copyright (C) Nanosurf AG - All Rights Reserved (2021)
 License - MIT"""
 
