@@ -375,11 +375,11 @@ class CmdTreeCompiler():
                         class_list.append("\n")
                 elif value_name == "vector":
                     class_list.append(f"    @property\n")
-                    class_list.append(f"    def value(self) -> {value_type}:\n")
+                    class_list.append(f"    def vector(self) -> {value_type}:\n")
                     class_list.append(f"        return {value_type}(self._context.get('{lua_tree_name}.vector'))\n")
                     class_list.append("\n")
-                    class_list.append(f"    @value.setter\n")
-                    class_list.append(f"    def value(self, new_val:{value_type}):\n")
+                    class_list.append(f"    @vector.setter\n")
+                    class_list.append(f"    def vector(self, new_val:{value_type}):\n")
                     class_list.append(f"        self._context.set('{lua_tree_name}.vector', {value_type}(new_val))\n")
                     class_list.append("\n")
                 else:
